// Generated by dts-bundle-generator v6.13.0

import { AxiosPromise } from 'axios';
import { Feature, FeatureCollection, GeometryObject, LineString, Polygon } from 'geojson';
import { Event, IControl, Map as MaplibreMap, Map as maplibreMap, MapGeoJSONFeature, MapMouseEvent, PointLike } from 'maplibre-gl';

declare enum ThemeType {
	CHRISTMAS = "christmas",
	HALLOWEEN = "halloween",
	MAPPY_BEE = "mappyBee",
	MAPXUS = "mapxus",
	LANDS_D = "landsD",
	COMMON = "common",
	MAPXUS_V2 = "mapxus_v2"
}
export interface IMapOption {
	map: maplibregl.Map;
	appId: string;
	secret: string;
	enableFloorControl?: boolean;
	enableBuildingSelector?: boolean;
	buildingId?: string;
	floor?: string;
	poiId?: string;
	hiddenOutdoor?: boolean;
	theme?: ThemeType;
	collapseCopyright?: boolean;
}
export type Listener = (param: Object) => any;
declare class DefinedEvent {
	private _type;
	private _target;
	constructor(type: string, data?: Object);
	get type(): string;
	set type(type: string);
	get target(): Evented;
	set target(target: Evented);
}
/**
 * Methods mixed in to other classes for event capabilities.
 *
 * @mixin Evented
 */
export declare class Evented {
	private _listeners;
	private _oneTimeListeners;
	private _eventedParent;
	private _eventedParentData;
	/**
	 * Adds a listener to a specified event type.
	 *
	 * @param {string} type The event type to add a listen for.
	 * @param {Function} listener The function to be called when the event is fired.
	 *   The listener function is called with the data object passed to `fire`,
	 *   extended with `target` and `type` properties.
	 * @returns {Object} `this`
	 */
	on(type: any, listener: Listener): this;
	/**
	 * Removes a previously registered event listener.
	 *
	 * @param {string} type The event type to remove listeners for.
	 * @param {Function} listener The listener function to remove.
	 * @returns {Object} `this`
	 */
	off(type: any, listener: Listener): this;
	/**
	 * Adds a listener that will be called only once to a specified event type.
	 *
	 * The listener will be called first time the event fires after the listener is registered.
	 *
	 * @param {string} type The event type to listen for.
	 * @param {Function} listener The function to be called when the event is fired the first time.
	 * @returns {Object} `this`
	 */
	once(type: string, listener: Listener): this;
	fire(event: DefinedEvent): this;
	/**
	 * Returns a true if this instance of Evented or any forwardeed instances of Evented have a listener for the specified type.
	 *
	 * @param {string} type The event type
	 * @returns {boolean} `true` if there is at least one registered listener for specified event type, `false` otherwise
	 * @private
	 */
	listens(type: string): boolean;
	/**
	 * Bubble all events fired by this instance of Evented to this parent instance of Evented.
	 *
	 * @returns {Object} `this`
	 * @private
	 */
	setEventedParent(parent: Evented, data?: Object | (() => Object)): this;
}
export interface IMultiLangName {
	default: string;
	en: string;
	"zh-Hans"?: string;
	"zh-Hant"?: string;
	ja?: string;
	ko?: string;
}
export interface IBbox {
	maxLat: number;
	maxLon: string;
	minLat: number;
	minLon: number;
}
export interface IBuilding {
	building: string;
	id: string;
	label_center: string;
	level_ids: string;
	level_names: string;
	name: string;
	"name:en": string;
	"name:zh-Hant": string;
	ordinals: string;
	"ref:venue": string;
	type: string;
}
export interface IFeatureBuilding extends MapGeoJSONFeature {
	properties: IBuilding;
	geometry: Polygon;
}
export interface ISearchBuilding {
	address: {
		[key in keyof IMultiLangName]: {
			housenumber: string;
			street: string;
		};
	};
	bbox: IBbox;
	buildingId: string;
	buildingOutlineId: number;
	city?: string;
	country: string;
	floors: {
		code: string;
		id: string;
		ordinal: number;
		signalMap: boolean;
		visualMap: boolean;
	}[];
	groundFloor: string;
	isPrivate: "yes" | "no";
	labelCenter: {
		lat: number;
		lon: number;
	};
	name: IMultiLangName;
	organization: string;
	region: string;
	signalMap: boolean;
	type: string;
	venueId: string;
	venueName: IMultiLangName;
}
/**
 * Indoor map core logic
 */
export declare class Indoor extends Evented {
	private _map;
	private _features;
	private _curBuildingId;
	private _curBuildingFeature;
	private _curOrdinal;
	private _curLevelId;
	private _curFloor;
	private _buildingFloors;
	private _buildingOrdinals;
	private _enableSwitch;
	private _enableSwitchBuilding;
	private _isHiddenOutdoor;
	private _indoorLayers;
	private _hasCustomLevelFill;
	private _curVenueId;
	private _curVenueFeature;
	private _footprints;
	private readonly _displayLevelSet;
	private _curVenueLevelMap;
	private _isSelectBuildingByClickMap;
	private static isFilterHasBeenReset;
	private static isLevel;
	private static isPoi;
	private static getBuildingPoint;
	constructor(map: maplibreMap, isHiddenOutdoor?: boolean);
	/** Turn on the indoor and outdoor switching */
	enableSwitch(): this;
	/** Turn off the indoor and outdoor switching */
	disableSwitch(): this;
	/** Turn on the buildings switching */
	enableSwitchBuilding(): this;
	/** Turn off the buildings switching */
	disableSwitchBuilding(): this;
	/**
	 * Get the selected building's floor list
	 * @return {string[]}
	 */
	get floors(): string[];
	/**
	 * Get the selected building's ordinal list
	 * @return {string[]}
	 */
	get ordinals(): string[];
	/**
	 * Get the selected building's id
	 * @returns {string}
	 */
	get buildingId(): string;
	/**
	 * Get current floor of the selected building
	 * @returns {string}
	 */
	get currentFloor(): string;
	/**
	 * Get current ordinal of selecting building
	 */
	get ordinal(): string | null;
	/**
	 * Get current venueId
	 */
	get venueId(): string | null;
	/**
	 * Get referred level of selecting building
	 * @returns {string}
	 */
	get refLevel(): string;
	/**
	 * Get the tiles of bbox
	 * @returns {IFeatureBuilding[]}
	 */
	get features(): MapGeoJSONFeature[];
	/**
	 * Get the feature by the specified id
	 * @param id: {string}
	 * @return {MapGeoJSONFeature | undefined}
	 */
	getFeature(id: string): MapGeoJSONFeature | undefined;
	/**
	 * Get the building at the point
	 * @param point: {PointLike}
	 * @return {IFeatureBuilding | undefined}
	 */
	getBuildingByPoint(point?: PointLike): IFeatureBuilding | undefined;
	/**
	 * Select a building feature
	 * @param feature: {IFeatureBuilding | null}
	 */
	selectBuilding(feature?: IFeatureBuilding | null): void;
	/**
	 * Switch to the building feature
	 * @param feature: {IFeatureBuilding}
	 */
	switchBuilding(feature: IFeatureBuilding): void;
	/**
	 * Select a building and pan to the building
	 * @param buildingId: {string}
	 * @param callback
	 */
	goToBuilding(buildingId: string, callback?: (feature: Feature<GeometryObject, IBuilding>) => void): void;
	/**
	 * Switch floor to filter features
	 * @param ordinal: {string}
	 */
	switchFloor(ordinal: string): void;
	/**
	 * Hide the outdoor map
	 * @param isHiddenOutdoor: {boolean}
	 */
	hiddenOutdoorLayer(isHiddenOutdoor: boolean): void;
	/** Update map after the style changed */
	updateLayers(): void;
	/** filter the layers */
	setFloorsFilter(): void;
	private _getConditionsExpression;
	private _loadData;
	private _init;
	private _load;
	private _clear;
	private _updateFilter;
	private _setPoiTextColor;
	private _addTextHaloColor;
	private _getFeatures;
	/**
	 * @description 获取 building ordinal: 有 floor 参数则返回该 floor 对应的 ordinal;
	 * @description 无则优先返回历史 ordinal 再是离地面层最近的 ordinal.
	 * @param buildingFeature: {MapGeoJSONFeature}
	 * @param floor?: {string}
	 * @private
	 */
	private _getBuildingOrdinal;
	/**
	 * 获取当前 building floor
	 * @private
	 */
	private _getBuildingFloor;
	/**
	 * @description Get building level_names and ordinals
	 * @param buildingFeature
	 * @private
	 */
	private _getBuildingProps;
	private _isNotCurrentFeature;
	private _setOutdoorLayersHidden;
	private _addCustomLevelFillLayer;
	private _setSelectedVenueState;
	private _setLayerTransparency;
	private _setBuildingHighlight;
	private _addBuildingHighlightLayer;
	private _filterBuildingHighlight;
	private _addDisplayLevels;
	private _removeDisplayLevels;
	private _setDisplayLevels;
	private _cacheCurVenueLevels;
	private _getDisplayLevels;
	private _getVenueOrdinal;
	private _getBuildingLevelByOrdinal;
	private _isBuildingLayer;
	private _isVenueLayer;
	/**
	 * @description 判断当前 building 是否为隐藏式 building，即点击的 building 无显示元素
	 * @param building
	 * @private
	 */
	private _isHiddenBuilding;
}
export interface IFloorsControlStyle {
	fontColor?: string;
	selectFontColor?: string;
	selectBoxColor?: string;
}
export interface IPoiEvent {
	lngLat: maplibregl.LngLat;
	originalEvent: Event;
	point: PointLike;
	feature: Feature<GeometryObject>;
}
export interface IFloorEvent {
	floor: string;
	ordinal: string;
	feature: Feature<GeometryObject>;
}
export interface IMapClickEvent extends Event {
	point?: PointLike;
	feature?: IFeatureBuilding;
}
export type TPosition = "top-right" | "top-left" | "bottom-right" | "bottom-left";
export declare class Map extends Evented {
	private _map;
	private _indoor;
	private _floorsControl;
	private _buildingFilterControl;
	private _enableFloorControl;
	private _enableBuildingSelector;
	private _poi;
	private _buildingId;
	private _initialHiddenLayers;
	private _attributionControl;
	private _mapZoom;
	private _dispatch;
	private static _getThemeStyleName;
	constructor(option: IMapOption);
	/**
	 * Map completely init
	 * @param {Function} callback all map operations
	 */
	renderComplete(callback: (event: Event) => void): void;
	/**
	 * Get indoor information: buildingId, floors...
	 * @returns {Indoor}
	 */
	getIndoor(): Indoor;
	/** Get map instance */
	getMap(): maplibreMap;
	/**
	 * Convert the POI text to the specified language
	 * @param language: {string}
	 */
	transformPoiTextFieldLanguage(language: string): void;
	/** Turn on indoor and outdoor switching */
	enableSwitch(): this;
	/** Turn off indoor and outdoor switching */
	disableSwitch(): this;
	/** Turn on the buildings switching */
	enableSwitchBuilding(): this;
	/** Turn off the buildings switching */
	disableSwitchBuilding(): this;
	/**
	 * To hide the outdoor map
	 * @param isHiddenOutdoor: {boolean}
	 */
	hiddenOutdoorLayer(isHiddenOutdoor: boolean): void;
	/**
	 * Get a list of floors of the selected building
	 * @returns {string[]}
	 */
	get floors(): string[];
	/**
	 * Get the current floor of the selected building
	 * @returns {string}
	 */
	get currentFloor(): string;
	/**
	 * Get the current ordinal of the selected building
	 */
	get ordinal(): string | null;
	/**
	 * Get venueId which the selected building belongs
	 */
	get venueId(): string | null;
	/**
	 * Get the selected building properties
	 * @returns {IBuilding | undefined}
	 */
	get building(): IBuilding | undefined;
	/**
	 * Get feature by the specified id
	 * @param id: {string}
	 */
	getFeature(id: string): MapGeoJSONFeature | undefined;
	/**
	 * Select the building feature to enter its indoor
	 * @param feature: {IFeatureBuilding}
	 */
	selectBuilding(feature: IFeatureBuilding): this;
	/**
	 * Switch the selected building to be the specified id
	 * @param buildingId: {string}
	 * @param callback
	 */
	switchBuilding(buildingId: string, callback?: (feature: Feature<GeometryObject, IBuilding>) => void): this;
	/**
	 * Switch to the specified floor
	 * @param floor: {string}
	 * @param callback
	 */
	switchFloor(floor: string, callback?: (object: IFloorEvent) => void): this;
	/**
	 * Listen for mouse click events on the map
	 * @param listener
	 * @return {unsubscribe}: to remove the event listener
	 */
	onMapClickListener(listener: (event: IMapClickEvent) => void): {
		unsubscribe: Function;
	};
	/**
	 * Listen for the indoor POI click events
	 * @param listener
	 * @return {unsubscribe}: to remove the event listener
	 */
	onIndoorPoiListener(listener: (result: IPoiEvent) => void): {
		unsubscribe: Function;
	};
	/**
	 * Listen for the selected floor changed event
	 * @param listener
	 * @return {unsubscribe}: to remove the event listener
	 */
	onFloorChangeListener(listener: (result: IFloorEvent) => void): {
		unsubscribe: Function;
	};
	/**
	 * Listen for the selected building changed event
	 * @param listener
	 * @return {unsubscribe}: to remove the event listener
	 */
	onBuildingChangeListener(listener: (feature: IFeatureBuilding | null) => void): {
		unsubscribe: Function;
	};
	/**
	 * Listen for the selected venue changed event
	 * @param {function} listener: (venueId: string | null, ordinal: string | null) => void
	 * @return {unsubscribe}: function to remove the event listener
	 */
	onVenueChangeListener(listener: (venueId: string | null, ordinal: string | null) => void): {
		unsubscribe: Function;
	};
	/** Hide the FloorControl */
	disableFloorControl(): this;
	/**
	 * set the FloorControl enabled
	 * @param position: TPosition
	 */
	enableFloorControl(position?: TPosition): this;
	/** Hide the BuildingSelector */
	disableBuildingSelector(): this;
	/**
	 * set the BuildingSelector enabled
	 * @param position: TPosition
	 */
	enableBuildingSelector(position?: TPosition): this;
	/**
	 * switch the map style
	 * @param theme: {string}
	 */
	switchTheme(theme: string): void;
	/**
	 * set the floorsControl's style
	 * @param style: {IFloorsControlStyle}
	 */
	setFloorsControlStyle(style: IFloorsControlStyle): void;
	private _setIndoorFilter;
	private _setStyle;
	private _addControl;
	private _defaultSetMapZoom;
	private _defaultSelectedBuilding;
	private _defaultSelectedPoi;
}
export type TCoordinates = [
	number,
	number
] | [
	number,
	number
][];
/**
 * Map marker
 * support all browser event
 * support floor and building switch
 * allow to define icon and scale
 */
export declare class Marker extends Evented {
	private _map;
	private _maplibreMap;
	private _coordinates;
	private _floor;
	private _buildingId;
	private readonly _sourceId;
	private readonly _layerId;
	private _imageName;
	private _imageUrl;
	private _imageScale;
	/**
	 * Determine whether the coordinates are multi array
	 *
	 * @private
	 * @returns {boolean}
	 */
	private static isMultiArray;
	constructor(map?: Map);
	/**
	 * @deprecated This method should not be used
	 * @param map
	 */
	addTo(map: Map): this;
	/**
	 * Set up marker handle event
	 *
	 * @public
	 * @param {string} type browser event type, eq. click、dbclick、mouseenter
	 * @param {function} callback marker event callback
	 */
	onEventListener(type: string, callback: (ev: MapMouseEvent) => void): void;
	/**
	 * Create marker content, must have coordinates
	 * Markers with the same building and floor can be appended by this function
	 * @public
	 * @param {number[] | number[][]} coordinates normal array is single point, two-dimensional array is multi points
	 * @param {string} floor optional, binding the marker floor, showing markers by floor
	 * @param {string} buildingId optional, binding the marker building, showing markers by building
	 */
	create(coordinates: TCoordinates, floor?: string, buildingId?: string): this;
	/**
	 * Remove marker data
	 * no data that will be hidden
	 *
	 * @public
	 */
	remove(): this;
	/**
	 * @deprecated This method should not be used
	 * @param floor
	 * @param buildingId
	 */
	switch(floor: string, buildingId: string): this;
	/**
	 * Get marker layer id value
	 *
	 * @public
	 * @returns {string}
	 */
	get layerId(): string;
	/**
	 * Get marker source id value
	 *
	 * @public
	 * @returns {string}
	 */
	get sourceId(): string;
	/**
	 * Setup define marker icon network url
	 *
	 * @public
	 * @param {string} imageUrl network url, allow format is png、gif、jpg
	 */
	setImageUrl(imageUrl: string): this;
	/**
	 * Setup define marker icon scale
	 *
	 * @public
	 * @param {number} imageScale 0.1 - 10
	 */
	setImageScale(imageScale: number): this;
	private _bindEvents;
	/**
	 * Create marker data, contain source and layer
	 * 1. create source
	 * 2. create layer
	 *
	 * @private
	 */
	private _createData;
	/**
	 * Load and set the marker icon.
	 *
	 * @private
	 * @param url
	 * @param {function} callback loaded callback function
	 */
	private _loadImage;
	/**
	 * Add marker data source, contain marker properties
	 *
	 * @private
	 */
	private _addSource;
	/**
	 * Add marker data layer, contain marker style
	 *
	 * @private
	 */
	private _addLayer;
	private _setFilter;
}
export declare class Poi {
	private _map;
	private _layers;
	private _dispatch;
	constructor(map: maplibregl.Map);
	/**
	 * Listen for the POI clicked event
	 * @param listener
	 * @return {unsubscribe}: to remove the event listener
	 */
	onPointClick(listener: (result: IPoiEvent) => void): {
		unsubscribe: Function;
	};
	/**
	 * Init the data after the style data is loaded
	 * @private
	 */
	private _loadData;
	/**
	 * 1. Get layer id is match `poi` name data
	 * 2. Init map on-click event
	 *
	 * @private
	 */
	private _init;
	/**
	 * Map on-click poi event
	 * if have poiClickFunction callback
	 * and then return the poi data to callback function
	 *
	 * @private
	 */
	private _initClick;
}
export declare class FloorsControl implements IControl {
	private _map;
	private _$container;
	private _indoor;
	private _$layout;
	private _$outer;
	private _$inner;
	private _$arrowUp;
	private _$arrowDown;
	private _floor;
	private _buildingId;
	private _ordinal;
	private _fontColor;
	private _selectFontColor;
	private _selectBoxColor;
	private _$currentButton;
	private _$floorControlButtons;
	private _enableFloorControl;
	private _position;
	private _dispatch;
	private static _$createFloor;
	constructor(map: Map, position?: TPosition);
	get position(): TPosition;
	get enabled(): boolean;
	onAdd(map: maplibreMap): HTMLElement;
	onRemove(): void;
	switchBuildingFloor(floor: string, callback?: (object: IFloorEvent) => void): void;
	onFloorClick(listener: (result: IFloorEvent) => void): {
		unsubscribe: Function;
	};
	switchFloor(ordinal: string, callback?: (object: IFloorEvent) => void): void;
	setStyle(style: IFloorsControlStyle): void;
	setLayoutHidden(isHidden: boolean): void;
	moveFloorControl(from: TPosition, to: TPosition): void;
	private _listener;
	/**
	 * Triggered when the user on-click on the building
	 * 1. click current building
	 * 2. click other building (new building)
	 * @param event {IBuildingSelectEvent}
	 */
	private _init;
	/**
	 * Triggered when the user move end on the map
	 */
	private _refresh;
	private _$createLayout;
	private _$configLayoutHeight;
	private _$configArrowDownTop;
	private _$showOrHideArrow;
	private _$showLayout;
	private _$hideLayout;
	private _$showArrowUp;
	private _$hideArrowUp;
	private _$showArrowDown;
	private _$hideArrowDown;
	private _$createFloors;
	private _$clearFloors;
	private _isEmptyFloors;
	private _isOverflowFloorMax;
	private _isEnableDisplay;
	private _scrollToClickedFloor;
	private _setCurrentButtonActive;
	private _floorClick;
	private _floorScroll;
	private _floorClickEvent;
	private _floorScrollEvent;
	private _bindEvent;
	private _getCurrentFloor;
	private _updateFloorControlStatus;
}
export declare class BuildingFilterControl implements maplibregl.IControl {
	private _map;
	private _indoor;
	private _buildingId;
	private _features;
	private _container;
	private _buildingNameLayout;
	private _buildingNameList;
	private _enableBuildingSelector;
	private readonly _position;
	constructor(map: Map, position?: TPosition);
	onAdd(map: MaplibreMap): HTMLElement;
	onRemove(): void;
	get position(): TPosition;
	get enabled(): boolean;
	setLayoutHidden(isHidden: boolean): void;
	moveBuildingFilter(from: TPosition, to: TPosition): void;
	private _loadData;
	private _init;
	private _refresh;
	private _select;
	private _load;
	private _getFeatureByName;
	private _buildingFilterIconCreate;
	private _buildingNameListCreate;
	private _buildingNameListUpdate;
	private _buildingNameListClean;
	private _buildingNameListHeight;
	private _buildingNameCreate;
	private _toggleList;
	private _buildingNameClickEvent;
	private _buildingToggleListEvent;
	private _$showLayout;
	private _$hideLayout;
}
export interface IResponseBuildings {
	buildings: ISearchBuilding[];
	total: number;
}
export interface IResponse<T> {
	code: number;
	message: string;
	result: T;
}
export declare class BuildingsService {
	private _api;
	private _request;
	constructor();
	searchByIds(ids: string | string[]): AxiosPromise<IResponse<IResponseBuildings>>;
	searchByDistance(keywords: string, center: number[], distance: number, offset?: number, page?: number): AxiosPromise<IResponse<IResponseBuildings>>;
	searchByBbox(keywords: string, bbox: number[], offset?: number, page?: number): AxiosPromise<IResponse<IResponseBuildings>>;
	searchByGlobal(keywords: string, offset?: number, page?: number): AxiosPromise<IResponse<IResponseBuildings>>;
	private _changedRes;
}
export interface ILocation {
	lat: number;
	lon: number;
}
export interface IPoi {
	address?: string;
	buildingId: string;
	category?: string;
	description?: string;
	email?: string;
	floor: string;
	id: string;
	location: ILocation;
	name: IMultiLangName;
	openingHours?: string;
	osmRefId?: number;
	phone?: string;
	poiId?: string;
	website?: string;
}
export interface IResponsePois {
	pois: IPoi[];
	total: number;
}
export interface IOrientationPoi {
	angle: number;
	buildingId: string;
	distance: number;
	floor: string;
	location: ILocation;
	name: object;
	poiId: string;
}
export interface IResponseOrientationPoi {
	orientationPois: IOrientationPoi[];
	total: number;
}
export declare class PoisService {
	private _api;
	private _categories;
	private _request;
	constructor();
	/**
	 * Search poi by poi ids, allow multi poi id
	 *
	 * @param ids: string | string[]
	 */
	searchByIds(ids: string | string[]): AxiosPromise<IResponse<IResponsePois>>;
	/**
	 * Search poi by radius distance of the center point
	 *
	 * @param category poi category
	 * @param center coordinate, [lng, lat]
	 * @param distance unit: meter, radius distance of the center point
	 * @param offset default 10
	 * @param page default 1
	 */
	searchByDistance(category: string, center: number[], distance: number, offset?: number, page?: number): AxiosPromise<IResponse<IResponsePois>>;
	/**
	 * Search poi by within bbox range
	 *
	 * @param keywords poi name
	 * @param bbox within, [min_lon, min_lat, max_lon, max_lat]
	 * @param offset default 10
	 * @param page default 1
	 */
	searchByBbox(keywords: string, bbox: number[], offset?: number, page?: number): AxiosPromise<IResponse<IResponsePois>>;
	/**
	 * Search poi by within building
	 *
	 * @param keywords poi name
	 * @param buildingId within the building
	 * @param offset default 10
	 * @param page default 1
	 */
	searchByBuildingId(keywords: string, buildingId: string, offset?: number, page?: number): AxiosPromise<IResponse<IResponsePois>>;
	/**
	 * Search poi category by building id or floor
	 *
	 * @param buildingId within the building
	 * @param floor option param, within floor
	 */
	searchCategory(buildingId: string, floor?: string): AxiosPromise<IResponse<string[]>>;
	/**
	 * Search orientation and poi
	 *
	 * @param angle the angle between cellphone's orientation and the north
	 * @param buildingId  within the building
	 * @param center the user's current position, [lon, lat]
	 * @param distance unit: meter, radius distance of the center point
	 * @param distanceSearchType search type default Point
	 * @param floor within floor
	 */
	searchOrientation(angle: number, buildingId: string, center: number[], distance: number, distanceSearchType: string, floor: string): AxiosPromise<IResponse<IResponseOrientationPoi>>;
	private _changedRes;
}
export interface IResponseRoute {
	hints: IRouteHints;
	info: IRouteInfo;
	paths: IRoutePaths[];
}
export interface IRouteHints {
	"visited_nodes.average": string;
	"visited_nodes.sum": string;
}
export interface IRouteInfo {
	copyrights: string[];
	took: number;
}
export interface IRoutePaths {
	ascend: number;
	bbox: number[];
	descend: number;
	details: object;
	distance: number;
	instructions: any;
	legs: number[];
	points: string | FeatureCollection<LineString>;
	points_encoded: boolean;
	snapped_waypoints: string;
	time: number;
	transfers: number;
	weight: number;
}
export declare class RouteService {
	private _api;
	private _request;
	constructor();
	/**
	 * Search wayfinding result, support across building query
	 *
	 * @param fromCoord from coordinate [lng, lat] (start point)
	 * @param toCoord to coordinate [lng, lat] (end point)
	 * @param fromFloor from building's floor (start point)
	 * @param toFloor to building's floor (end point)
	 * @param fromBuildingId from building (start point)
	 * @param toBuildingId to building (end point)
	 * @param vehicle option param, Available values : foot, wheelchair, default foot
	 * @param locale option param, result return language
	 * @param toDoor option param, if end point result in the room, wayfinding result will only to the door, default `true`
	 */
	search(fromCoord: number[], toCoord: number[], fromFloor: string, toFloor: string, fromBuildingId: string, toBuildingId: string, vehicle?: string, locale?: string, toDoor?: boolean): AxiosPromise<IResponse<IResponseRoute>>;
}
export declare const version: string;

export {};
